@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Template::Resolver;
-$Template::Resolver::VERSION = '1.02';
+$Template::Resolver::VERSION = '1.03';
 # ABSTRACT: A powerful, and simple, library for resolving placeholders in templated files
 # PODNAME: Template::Resolver
 
@@ -86,7 +86,7 @@ sub resolve {
         croak('Must provide one of [content, handle, filename]');
     }
 
-    $content =~ s/\$\{$key(?:_(.*?))?\{(.*?)\}\}/$self->_get_property($2,$1)/eg;
+    $content =~ s/\$\{$key(?:_(.*?))?\{(.*?)\}\}/$self->_get_property($2,$1)/egs;
     return $content;
 }
 
@@ -102,7 +102,7 @@ Template::Resolver - A powerful, and simple, library for resolving placeholders
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 SYNOPSIS
 
